package verschiebeSpiel;

import java.awt.*;
import javax.swing.*;

@SuppressWarnings("serial")
public class Hauptfenster extends JFrame {

	/** Spiele Logik */
	Logik logik = new Logik();
	
	/** VerschiebeSpiel Spielfeld */
	Spielfeld spielfeld = new Spielfeld(this.logik);
	
	/** Spiele-Navigator, rechts neben dem Hauptfenster */
	Navigator navigator = new Navigator(this);
	
	/**
	 * Konstruktor der Klasse <code>Hauptfenster</code>. Erstellt alle benoetigten
	 * Komponenten wie Menue, Spielfeld und Steuerungsfenster, und initialisiert die
	 * Spiel-Logik.  
	 */
	public Hauptfenster() {
		this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		this.setTitle("VerschiebeSpiel");
		this.setLocationRelativeTo(null);

		this.getContentPane();
		
		/** Listener von der Logik zum Spielfeld */
		ListenerButton listenerButton = new ListenerButton(logik);

		/** Spielfeld hinzufuegen und Zeichen lassen */
		spielfeld.setListener(listenerButton);
		spielfeld.setNavigator(navigator);
		spielfeld.zeichneFeld();

		this.add(spielfeld, BorderLayout.CENTER);

		/** Fenster Listener als Komonenten des Hauptfensters */
		this.addComponentListener(new ListenerFenster(this.navigator));
		
		/** MenuBar zum Hauptfenster hinzufuegen */
		this.setJMenuBar(new MenuBar(new ListenerMenu(this)));

		/** Standart Einstellungen fuer das Fenster */
		this.setResizable(false);
		this.setLookAndFeel("javax.swing.plaf.metal.MetalLookAndFeel");
		this.pack();
		this.setVisible(true);
	}

	public static void main(String[] args) {
		new Hauptfenster();
	}

	/**
	 * Legt ein Look-And-Feel fest und aktualisiert dabei das Hauptfenster,
	 * den <code>navigator</code> und den <code>helpDialog</code>.
	 * @param lookAndFeel Klassenname des Designs
	 */
	public void setLookAndFeel(String lookAndFeel) {
		try {
			UIManager.setLookAndFeel(lookAndFeel);
			SwingUtilities.updateComponentTreeUI(this);
		} catch (Exception e) {
			System.out.println("setLookAndFeel Exception " + e);
		}

		this.pack();
	}
	
	/**
	 * Startet ein neues Spiel mit dem angegeben Level. Dabei werden die aktuellen
	 * Fenster und die Spiellogik zerstoert und ein neues Hauptfenster an alter 
	 * Stelle neu erstellt.
	 * @param level Level-Name, mit dem das neue Spiel begonnen werden soll 
	 */
	public void startNewGame() {			
		this.navigator.dispose();
		this.dispose();
		
		new Hauptfenster();
	}

}