package verschiebeSpiel;

import javax.swing.ButtonGroup;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JRadioButtonMenuItem;
import javax.swing.UIManager;
import javax.swing.UIManager.LookAndFeelInfo;

@SuppressWarnings("serial")
public class MenuBar extends JMenuBar {
	/** ActionCommand-String zum Anzeigen des Spielbeschreibung */
	static public final String CMD_NEWGAME = "newGame";
	
	/** ActionCommand-String zum Schliessen von Dialogfenstern */
	static public final String CMD_CLOSEWINDOW = "closeWindow";
	
	/**
	 * Verbindung zum Event-Handler, wird lediglich zum Setzen der Listener fuer die
	 * einzelnen Menuepunkte benoetigt.
	 */
	private ListenerMenu listener;

	/**
	 * Konstruktor der Klasse <code>MenuBar</code>
	 * 
	 * @param listener Menuelistener, der auf die Menue-Ereignisse reagiert, vom Typ <code>ListenerMenu</code> 
	 */
	public MenuBar(ListenerMenu listener) {
		this.listener = listener;
		
		// Menue: VerschiebeSpiel
		JMenu menuVerschiebeSpiel = new JMenu("VerschiebeSpiel");
		menuVerschiebeSpiel.setMnemonic('v');
		menuVerschiebeSpiel.add(this.createMenuItem("Neues Spiel", MenuBar.CMD_NEWGAME));
		menuVerschiebeSpiel.add(this.createMenuItem("Beenden", MenuBar.CMD_CLOSEWINDOW));
		this.add(menuVerschiebeSpiel);
		
		// Menue: Konfiguration
		JMenu menuConfiguration = new JMenu("Konfigurieren");
		menuConfiguration.setMnemonic('k');
		menuConfiguration.add(this.createMenuItemLookAndFeel());
		this.add(menuConfiguration);
	}

	/**
	 * Hilfsmethode zum Erzeugen des Menuepunkts "Look and Feel". Dieses <code>JMenuItem</code> selbst
	 * hat (dynamisch generierte) Untermenuepunkte vom Typ <code>JRadioButtomMenuItem</code>. Die
	 * Menuepunkte werden mit Hilfe der Klasse <code>UIManager</code> generiert. Sorgt beim Erstellen 
	 * dafuer, dass das eingestellte "Look and Feel" selektiert ist.
	 * 
	 * @return <code>JMenuItem</code> "Look and Feel" mit Untermenuepunkten 
	 */
	private JMenuItem createMenuItemLookAndFeel()
	{
		LookAndFeelInfo[] lnf =	UIManager.getInstalledLookAndFeels();

		JMenuItem menuItemLookAndFeel = new JMenu("Look and Feel");

		ButtonGroup groupLookAndFeel = new ButtonGroup();
		String lookandfeel = UIManager.getLookAndFeel().getName();
		for(int i = 0; i < lnf.length; i++) {		
			menuItemLookAndFeel.add(this.createRadioMenuItem(lnf[i].getName(), 
									lnf[i].getClassName(), 
									groupLookAndFeel,
									lookandfeel.equals(lnf[i].getName())));
		}
		
		return menuItemLookAndFeel;
	}
	
	/**
	 * Erzeugt ein <code>JRadioButtonMenuItem</code>. Als ActionListener wird der
	 * der dem Konstruktor uebergebene Listener vom Typ <code>ListenerMenu</code> eingestellt.
	 * 
	 * @param title Im Menue erscheinender Text des Menuepunkts
	 * @param command Das geworfene ActionCommand, wenn der Menuepunkt ausgewaehlt wird
	 * @param group Die <code>ButtonGroup</code>, zu der der Menuepunkt gehoert
	 * @param selected Wahrheitswert, welcher <code>true</code> ist, wenn der Menuepunkt selektiert ist, ansonsten <code>false</code>
	 * @return generiertes <code>JRadioButtonMenuItem</code> 
	 */
	private JRadioButtonMenuItem createRadioMenuItem(String title, String command, ButtonGroup group, boolean selected)
	{
		JRadioButtonMenuItem menuitem = new JRadioButtonMenuItem(title);	
		menuitem.setActionCommand(command);
		menuitem.setSelected(selected);
		menuitem.addActionListener(this.listener);
		group.add(menuitem);
		return menuitem;
	}

	/**
	 * Erzeugt ein <code>JMenuItem</code>. Als ActionListener wird der
	 * der dem Konstruktor uebergebene Listener vom Typ <code>ListenerMenu</code> eingestellt.
	 * 
	 * @see javax.swing.JMenuItem
	 * @param title Im Menue erscheinender Text des Menuepunkts
	 * @param command Das geworfene ActionCommand, wenn der Menuepunkt ausgewaehlt wird
	 * @return generiertes <code>JMenuItem</code> 
	 */
	private JMenuItem createMenuItem(String title, String command)
	{
		JMenuItem menuitem = new JMenuItem(title);
		menuitem.addActionListener(this.listener);
		menuitem.setActionCommand(command);
		return menuitem;
	}
}
